diff --git a/core/modules/system/tests/src/Functional/Entity/EntityReferenceSelection/EntityReferenceSelectionAccessTest.php b/core/modules/system/tests/src/Functional/Entity/EntityReferenceSelection/EntityReferenceSelectionAccessTest.php
index 07468af5c5..8bdfe5d025 100644
--- a/core/modules/system/tests/src/Functional/Entity/EntityReferenceSelection/EntityReferenceSelectionAccessTest.php
+++ b/core/modules/system/tests/src/Functional/Entity/EntityReferenceSelection/EntityReferenceSelectionAccessTest.php
@@ -341,8 +341,8 @@ public function testUserHandler() {
       ],
       [
         'arguments' => [
-          ['Anonymous', 'CONTAINS'],
-          ['anonymous', 'CONTAINS'],
+          ['Visitor', 'CONTAINS'],
+          ['visitor', 'CONTAINS'],
         ],
         'result' => [
           'user' => [
diff --git a/core/modules/user/config/install/user.role.anonymous.yml b/core/modules/user/config/install/user.role.anonymous.yml
index c89e023b03..1f3f67b258 100644
--- a/core/modules/user/config/install/user.role.anonymous.yml
+++ b/core/modules/user/config/install/user.role.anonymous.yml
@@ -2,7 +2,7 @@ langcode: en
 status: true
 dependencies: {  }
 id: anonymous
-label: 'Anonymous user'
+label: 'Visitor'
 weight: 0
 is_admin: false
 permissions: {  }
diff --git a/core/modules/user/config/install/user.role.authenticated.yml b/core/modules/user/config/install/user.role.authenticated.yml
index 5da2abdd93..a753ad09c9 100644
--- a/core/modules/user/config/install/user.role.authenticated.yml
+++ b/core/modules/user/config/install/user.role.authenticated.yml
@@ -2,7 +2,7 @@ langcode: en
 status: true
 dependencies: {  }
 id: authenticated
-label: 'Authenticated user'
+label: 'Registered user'
 weight: 1
 is_admin: false
 permissions: {  }
diff --git a/core/modules/user/config/install/user.settings.yml b/core/modules/user/config/install/user.settings.yml
index 8372ccdb73..a47ac414ff 100644
--- a/core/modules/user/config/install/user.settings.yml
+++ b/core/modules/user/config/install/user.settings.yml
@@ -1,4 +1,4 @@
-anonymous: Anonymous
+anonymous: Visitor
 verify_mail: true
 notify:
   cancel_confirm: true
diff --git a/core/tests/Drupal/FunctionalTests/Installer/InstallerTranslationMultipleLanguageTest.php b/core/tests/Drupal/FunctionalTests/Installer/InstallerTranslationMultipleLanguageTest.php
index 0f06d17a5c..2cd775290c 100644
--- a/core/tests/Drupal/FunctionalTests/Installer/InstallerTranslationMultipleLanguageTest.php
+++ b/core/tests/Drupal/FunctionalTests/Installer/InstallerTranslationMultipleLanguageTest.php
@@ -49,8 +49,8 @@ protected function getPo($langcode) {
 msgid "Save and continue"
 msgstr "Save and continue $langcode"
 
-msgid "Anonymous"
-msgstr "Anonymous $langcode"
+msgid "Visitor"
+msgstr "Visitor $langcode"
 
 msgid "Language"
 msgstr "Language $langcode"
@@ -113,14 +113,14 @@ public function testTranslationsLoaded() {
     if ($this->langcode == 'de') {
       // Active configuration should be in German and no German override should
       // exist.
-      $this->assertEqual($config->get('anonymous'), 'Anonymous de');
+      $this->assertEqual($config->get('anonymous'), 'Visitor de');
       $this->assertEqual($config->get('langcode'), 'de');
       $this->assertTrue($override_de->isNew());
 
       if ($this->profile == 'testing_multilingual_with_english') {
         // English is already added in this profile. Should make the override
         // available.
-        $this->assertEqual($override_en->get('anonymous'), 'Anonymous');
+        $this->assertEqual($override_en->get('anonymous'), 'Visitor');
       }
       else {
         // English is not yet available.
@@ -130,7 +130,7 @@ public function testTranslationsLoaded() {
         $edit = ['predefined_langcode' => 'en'];
         $this->drupalPostForm('admin/config/regional/language/add', $edit, t('Add language'));
         $override_en = $language_manager->getLanguageConfigOverride('en', 'user.settings');
-        $this->assertEqual($override_en->get('anonymous'), 'Anonymous');
+        $this->assertEqual($override_en->get('anonymous'), 'Visitor');
       }
 
       // Activate a module, to make sure that config is not overridden by module
@@ -146,16 +146,16 @@ public function testTranslationsLoaded() {
     }
     else {
       // Active configuration should be English.
-      $this->assertEqual($config->get('anonymous'), 'Anonymous');
+      $this->assertEqual($config->get('anonymous'), 'Visitor');
       $this->assertEqual($config->get('langcode'), 'en');
       // There should not be an English override.
       $this->assertTrue($override_en->isNew());
       // German should be an override.
-      $this->assertEqual($override_de->get('anonymous'), 'Anonymous de');
+      $this->assertEqual($override_de->get('anonymous'), 'Visitor de');
     }
 
     // Spanish is always an override (never used as installation language).
-    $this->assertEqual($override_es->get('anonymous'), 'Anonymous es');
+    $this->assertEqual($override_es->get('anonymous'), 'Visitor es');
 
   }
 
@@ -163,7 +163,7 @@ public function testTranslationsLoaded() {
    * Helper function to verify that the expected strings are translated.
    */
   protected function verifyImportedStringsTranslated() {
-    $test_samples = ['Save and continue', 'Anonymous', 'Language'];
+    $test_samples = ['Save and continue', 'Visitor', 'Language'];
     $langcodes = ['de', 'es'];
 
     foreach ($test_samples as $sample) {
diff --git a/core/tests/Drupal/FunctionalTests/Installer/InstallerTranslationTest.php b/core/tests/Drupal/FunctionalTests/Installer/InstallerTranslationTest.php
index c38d4719fc..f7a5e29fdd 100644
--- a/core/tests/Drupal/FunctionalTests/Installer/InstallerTranslationTest.php
+++ b/core/tests/Drupal/FunctionalTests/Installer/InstallerTranslationTest.php
@@ -98,7 +98,7 @@ public function testInstaller() {
     $this->assertRaw('classy/css/components/action-links.css');
 
     // Verify the strings from the translation files were imported.
-    $test_samples = ['Save and continue', 'Anonymous'];
+    $test_samples = ['Save and continue', 'Visitor'];
     foreach ($test_samples as $sample) {
       $edit = [];
       $edit['langcode'] = 'de';
@@ -116,7 +116,7 @@ public function testInstaller() {
     $config = \Drupal::config('user.settings');
     $override_de = $language_manager->getLanguageConfigOverride('de', 'user.settings');
     $override_en = $language_manager->getLanguageConfigOverride('en', 'user.settings');
-    $this->assertEqual($config->get('anonymous'), 'Anonymous de');
+    $this->assertEqual($config->get('anonymous'), 'Visitor de');
     $this->assertEqual($config->get('langcode'), 'de');
     $this->assertTrue($override_de->isNew());
     $this->assertTrue($override_en->isNew());
@@ -126,7 +126,7 @@ public function testInstaller() {
     $this->drupalPostForm('admin/config/regional/language/add', $edit, t('Add language'));
     $override_en = $language_manager->getLanguageConfigOverride('en', 'user.settings');
     $this->assertFalse($override_en->isNew());
-    $this->assertEqual($override_en->get('anonymous'), 'Anonymous');
+    $this->assertEqual($override_en->get('anonymous'), 'Visitor');
   }
 
   /**
@@ -145,8 +145,8 @@ protected function getPo($langcode) {
 msgid "Save and continue"
 msgstr "Save and continue $langcode"
 
-msgid "Anonymous"
-msgstr "Anonymous $langcode"
+msgid "Visitor"
+msgstr "Visitor $langcode"
 
 msgid "Resolve all issues below to continue the installation. For help configuring your database server, see the <a href="https://www.drupal.org/docs/8/install">installation handbook</a>, or contact your hosting provider."
 msgstr "Beheben Sie alle Probleme unten, um die Installation fortzusetzen. Informationen zur Konfiguration der Datenbankserver finden Sie in der <a href="https://www.drupal.org/docs/8/install">Installationshandbuch</a>, oder kontaktieren Sie Ihren Hosting-Anbieter."

diff --git a/core/modules/comment/tests/src/Functional/CommentInterfaceTest.php b/core/modules/comment/tests/src/Functional/CommentInterfaceTest.php
index 2d3dcaa5d1..a32dd8b658 100644
--- a/core/modules/comment/tests/src/Functional/CommentInterfaceTest.php
+++ b/core/modules/comment/tests/src/Functional/CommentInterfaceTest.php
@@ -71,7 +71,7 @@ public function testCommentInterface() {
     $comment = $this->postComment($this->node, $comment_text, $subject_text, TRUE);
     $this->assertTrue($this->commentExists($comment), 'Comment found.');
 
     // Comment as anonymous with preview required.
     $this->drupalLogout();
     user_role_grant_permissions(RoleInterface::ANONYMOUS_ID, ['access content', 'access comments', 'post comments', 'skip comment approval']);
     $anonymous_comment = $this->postComment($this->node, $this->randomMachineName(), $this->randomMachineName(), TRUE);
@@ -101,9 +101,9 @@ public function testCommentInterface() {
       '@title' => $comment->getSubject(),
     ]));
 
     // Test changing the comment author to "Anonymous".
     $comment = $this->postComment(NULL, $comment->comment_body->value, $comment->getSubject(), ['uid' => '']);
-    $this->assertTrue($comment->getAuthorName() == t('Anonymous') && $comment->getOwnerId() == 0, 'Comment author successfully changed to anonymous.');
+    $this->assertTrue($comment->getAuthorName() == t('Visitor') && $comment->getOwnerId() == 0, 'Comment author successfully changed to Visitor.');
 
     // Test changing the comment author to an unverified user.
     $random_name = $this->randomMachineName();
@@ -71,7 +71,7 @@ public function testCommentInterface() {
     $this->assertTrue($this->commentExists($comment), 'Comment found.');
 
-    // Comment as anonymous with preview required.
+    // Comment as visitor with preview required.
     $this->drupalLogout();
     user_role_grant_permissions(RoleInterface::ANONYMOUS_ID, ['access content', 'access comments', 'post comments', 'skip comment approval']);
@@ -101,9 +101,9 @@ public function testCommentInterface() {
     ]));
 
-    // Test changing the comment author to "Anonymous".
+    // Test changing the comment author to "Visitor".
     $comment = $this->postComment(NULL, $comment->comment_body->value, $comment->getSubject(), ['uid' => '']);
diff --git a/core/modules/locale/tests/src/Functional/LocaleImportFunctionalTest.php b/core/modules/locale/tests/src/Functional/LocaleImportFunctionalTest.php
index 9342c6ed84..bbc37cb75b 100644
--- a/core/modules/locale/tests/src/Functional/LocaleImportFunctionalTest.php
+++ b/core/modules/locale/tests/src/Functional/LocaleImportFunctionalTest.php
@@ -295,8 +295,8 @@ public function testConfigPoFile() {
         'message',
       ],
       'user.role.anonymous' => [
-        'Anonymous user',
-        'Névtelen felhasználó',
+        'Visitor',
+        'látogató',
         'label',
       ],
     ];
@@ -356,9 +356,9 @@ public function testConfigtranslationImportingPoFile() {
       'langcode' => $langcode,
     ]);
 
     // Check that the 'Anonymous' string is translated.
     $config = \Drupal::languageManager()->getLanguageConfigOverride($langcode, 'user.settings');
-    $this->assertEqual($config->get('anonymous'), 'Anonymous German');
+    $this->assertEqual($config->get('anonymous'), 'Visitor German');
   }
 
   /**
@@ -625,8 +625,8 @@ public function getPoFileWithConfig() {
 msgid "@site is currently under maintenance. We should be back shortly. Thank you for your patience."
 msgstr "@site karbantartás alatt áll. Rövidesen visszatérünk. Köszönjük a türelmet."
 
-msgid "Anonymous user"
-msgstr "Névtelen felhasználó"
+msgid "Visitor"
+msgstr "látogató"
 
 EOF;
   }
@@ -644,8 +644,8 @@ public function getPoFileWithConfigDe() {
 "Content-Transfer-Encoding: 8bit\\n"
 "Plural-Forms: nplurals=2; plural=(n > 1);\\n"
 
-msgid "Anonymous"
-msgstr "Anonymous German"
+msgid "Visitor"
+msgstr "Visitor German"
 
 msgid "German"
 msgstr "Deutsch"
@@ -356,9 +356,9 @@ public function testConfigtranslationImportingPoFile() {
     ]);
 
-    // Check that the 'Anonymous' string is translated.
+    // Check that the 'Visitor' string is translated.
     $config = \Drupal::languageManager()->getLanguageConfigOverride($langcode, 'user.settings');